@@ -8,6 +8,8 @@ use apexl\Io\includes\Hook;
 use apexl\Io\includes\Routes;
 use apexl\Io\includes\System;
 use apexl\Io\modules\email\services\templateService;
+use apexl\Io\modules\subscription\entities\subscriptionEntity;
+use apexl\Io\modules\subscription\services\subscriptionService;
 use apexl\Io\modules\user\entities\refreshTokenEntity;
 use apexl\Io\modules\user\entities\sessionEntity;
 use apexl\Io\modules\user\entities\userEntity;
@@ -212,8 +214,9 @@ class userController extends Controller
                 return System::asJson($response, [], 403);
             }
             //does this user already exist?
+            $user = new userEntity();
             $user->getUserByEmail($body->email);
-            if ($user->email !== '' && $user->email !== '0') {
+            if (isset($user->id) && $user->id > 0) {
                 $this->output::addMessage($this->path->getRouteName($request).'.validation', 'error', 'A user with that email address already exists.');
                 $this->output::addResponse($request, [], false); //added so we can hook into this elsewhere.
                 return System::asJson($response, [], 400);
@@ -251,6 +254,12 @@ class userController extends Controller
 
         if (isset($body->active) && $this->currentUser->isAllowed('ChangeUserActiveState')) {
             $user->active = (int)$body->active;
+            unset($body->active);
+        }
+
+        if (isset($body->suspended) && $this->currentUser->isAllowed('ChangeUserActiveState')) {
+            $user->suspended = (int)$body->suspended;
+            unset($body->suspended);
         }
 
         //we need to unset all roles if we're setting any at all, so check we can do this on first pass.
@@ -287,6 +296,12 @@ class userController extends Controller
             $this->output::addMetadata($this->path->getRouteName($request).'.complete', 'entityId', $user->id);
             $this->output::addMessage($this->path->getRouteName($request).'.complete', 'success', $user->getNiceName().' '. ($id ? 'updated' : 'created'));
             $this->output::addResponse($request, $user->getData()); //added so we can hook into this elsewhere.
+
+            $routeName = 'userEntity.display.get';
+            $path = Routes::getRoutePattern($routeName . '.override', ['id' => $user->id]);
+            if ($route = ($path ? $path : Routes::getRoutePattern($routeName, ['id' => $user->id]))) {
+                $this->output->addMetadata($this->path->getRouteName($request) . '.redirect', 'redirect', $route);
+            }
             return System::asJson($response);
         }
         $this->output::addMessage($this->path->getRouteName($request).'.validation', 'error', 'Not all of the data provided is valid');
@@ -353,7 +368,7 @@ class userController extends Controller
         $frontEndDomain = System::getVariable('site_from_domain') ?? $this->config->app->site->frontend_domain ?? 'localhost';
 
         //move to config.
-        $link = rtrim($frontEndDomain, '/').'/'.Routes::getRoutePattern('user.forgot-password.hash', ['hash' => $string]);;
+        $link = rtrim($frontEndDomain, '/').'/'.ltrim('/'.Routes::getRoutePattern('user.forgot-password.hash', ['hash' => $string]), '/');
 
         //$this->mailer->SMTPDebug = 1;
         $this->mailer->setFrom($from, $fromName);
@@ -377,7 +392,9 @@ class userController extends Controller
         $filters = $this->buildFilterConditions($entity, $params);
         //$users = $entity->loadMultiple($filters, $params['orderBy'] ?? []); // Note - this inclueds access control with correct config
 
-        $entityData = $entity->loadByPage($params, $filters, $params['orderBy'] ?? []);
+        $lookupKey = Hook::processHook('user_entity_search_lookup', null, $params);
+
+        $entityData = $entity->loadByPage($params, $filters, $params['orderBy'] ?? [], $lookupKey);
 
         $entityData['tableHeader'] = ['ID', 'Name', 'Validated/ Active?', 'Email Address', 'Company', 'Last Login', 'Created', 'Roles'];
 
@@ -406,6 +423,22 @@ class userController extends Controller
 
         return System::asJson($response, $entityData);
     }
+
+    public function buildFilterConditions($entity, $params, $validFields = []): array
+    {
+        $filters = parent::buildFilterConditions($entity, $params, ['customerName']);
+
+        if(isset($filters['email'])) {
+            $filters['email'][1] = '%' . $filters['email'][1] . '%';
+            $filters['email'][2] = 'LIKE';
+        }
+        if(isset($filters['customerName'])) {
+            $filters['customerName'] = ['CONCAT(first_name, " ", last_name)', '%'.$params['customerName'].'%', 'LIKE'];
+        }
+
+        return $filters;
+    }
+
     public function updateSettings(Request $request, Response $response, $args)
     {
         $user = currentUser::getCurrentUser();
@@ -417,4 +450,25 @@ class userController extends Controller
 
         return System::asJson($response, ['success' => false]);
     }
+
+    public function suspendUserNow(Request $request, Response $response, $args)
+    {
+        $userEntity = new userEntity();
+        $userEntity->load($args['id']);
+        if (isset($userEntity->id) && $userEntity->id > 0) {
+            if (class_exists('apexl\Io\modules\subscription\entities\subscriptionEntity')) { // check to see if module is installed
+                $subscriptionService = new subscriptionService();
+                $subscriptionService->suspendAllUserSubscriptions($userEntity);
+            }
+
+        $userEntity->suspended = 1;
+        $userEntity->active = 0;
+        $userEntity->store();
+        $this->output::addMessage('user.suspend', 'success', $userEntity->first_name . ' ' . $userEntity->last_name . ' access disabled and subscriptions pending imminent suspension.');
+
+            return System::asJson($response, ['success' => true]);
+        }
+
+        return System::asJson($response, ['success' => false, 'reason' => 'User Not Found']);
+    }
 }
