@@ -308,10 +308,6 @@ class userController extends Controller
             $activeField = (new checkboxField('active'))->setLabel('Active (Can Login)');
             $suspendedField = (new checkboxField('suspended'))->setLabel('Suspended');
             $invoiceNameField = (new inputField('invoice_name_override'))->setLabel('Invoice Name Override');
-        } else {
-            $activeField = (new inputField('active'))->setInputType('hidden');
-            $suspendedField = (new inputField('suspended'))->setInputType('hidden');
-            $invoiceNameField = (new inputField('invoice_name_override'))->setInputType('hidden');
         }
 
         if ($id = $args[$user->primaryKey] ?? false) {
@@ -321,14 +317,18 @@ class userController extends Controller
             $form->addField($form->getFormField('last_name')->setValue($user->last_name));
             $form->addField($form->getFormField('email')->setValue($user->email));
 
-            $activeField->setValue($user->active);
-            $suspendedField->setValue($user->suspended);
-            $invoiceNameField->setValue($user->invoice_name_override ?? null);
+            if ($this->currentUser->isAllowed('ChangeUserActiveState')) {
+                $activeField->setValue($user->active == 1);
+                $suspendedField->setValue($user->suspended == 1);
+                $invoiceNameField->setValue($user->invoice_name_override ?? null);
+            }
         }
 
-        $form->addField($activeField);
-        $form->addField($suspendedField);
-        $form->addField($invoiceNameField);
+        if ($this->currentUser->isAllowed('ChangeUserActiveState')) {
+            $form->addField($activeField);
+            $form->addField($suspendedField);
+            $form->addField($invoiceNameField);
+        }
 
         //allow other modules to add form fields.
         $form = Hook::processHook('displayFormRender', $form, $user, 'userEditForm');
